@@ -8,13 +8,7 @@ REQUEST_TIMEOUT = 5
 ASYNC_TIMEOUT = 20
 
 # 异步aiohttp限制 limit
-ASYNC_REQUEST_LIMIT = 256
-
-# 请求重定向
-FOLLOW_REDIRECTS = True
-
-# 全部请求方式
-REQUEST_METHOD_LIST = ("GET", "POST", "DELETE", "PATCH", "HEAD", "PUT", "OPTIONS")
+ASYNC_REQUEST_LIMIT = 128
 
 # 下载保存文件夹
 FILE_PATH = "/storage/emulated/0/m3u8"
